@@ -1,9 +1,11 @@
-from django.test import tag, TestCase
+import pytest
+from django.test import TestCase
 
-from django_afip import factories, models
+from django_afip import factories
+from django_afip import models
 
 
-@tag('live')
+@pytest.mark.live
 class LiveAfipTestCase(TestCase):
     """
     Base class for AFIP-WS related tests.
@@ -21,7 +23,7 @@ class LiveAfipTestCase(TestCase):
         LiveAfipTestCase.taxpayer = factories.TaxPayerFactory(pk=1)
 
         if not LiveAfipTestCase.ticket:
-            ticket = models.AuthTicket.objects.get_any_active('wsfe')
+            ticket = models.AuthTicket.objects.get_any_active("wsfe")
             LiveAfipTestCase.ticket = ticket
 
         LiveAfipTestCase.ticket.save()
@@ -31,6 +33,6 @@ class PopulatedLiveAfipTestCase(LiveAfipTestCase):
     def setUp(self):
         """Populate AFIP metadata and create a TaxPayer and PointOfSales."""
         super().setUp()
-        models.populate_all()
+        models.load_metadata()
         taxpayer = models.TaxPayer.objects.first()
         taxpayer.fetch_points_of_sales()
